# Generated by roxygen2: do not edit by hand

export(compnc)
export(compnc_robustness)
export(coverage)
export(extract_traits)
export(merge_dataset)
export(pnc)
export(pnc_robustness)
export(simulate_K_trait)
export(simulate_lambda_trait)
importFrom(ape,Ntip)
importFrom(ape,drop.tip)
importFrom(ape,stree)
importFrom(geiger,lambdaTree)
importFrom(phytools,fastBM)
importFrom(phytools,phylosig)
importFrom(phytools,rescale)
importFrom(stats,complete.cases)
importFrom(stats,na.omit)
importFrom(stats,prcomp)
importFrom(stats,sd)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
